Jmbo Facebook
=============
**Fetch facebook page updates.**

.. contents:: Contents
    :depth: 5

Installation
------------

#. Install or add ``jmbo-facebook`` to your Python path.

#. Add ``jmbo_facebook`` to your ``INSTALLED_APPS`` setting.


Usage
-----

Specify the Facebook application identifier and secret in your settings file::

    JMBO_FACEBOOK = {'app_id': 'yourappid', 'app_secret': 'yourappsecret'}

